@@ -17,7 +17,7 @@ package PostScript::Report::Role::Component;
 # ABSTRACT: Something that can be drawn
 #---------------------------------------------------------------------
 
-our $VERSION = '0.01';
+our $VERSION = '0.03';
 
 use Moose::Role;
 use MooseX::AttributeTree ();
@@ -60,6 +60,14 @@ has align => (
 );
 
 
+has background => (
+  is       => 'ro',
+  isa      => Color,
+  coerce   => 1,
+  writer   => '_set_background', # Used by Report::_stripe_detail
+);
+
+
 has border => (
   is  => 'ro',
   isa => BorderStyle,
@@ -90,6 +98,19 @@ has line_width => (
 
 requires 'draw';
 
+before draw => sub {
+  my ($self, $x, $y, $rpt) = @_;
+
+  if (defined(my $background = $self->background)) {
+    $rpt->ps->add_to_page( sprintf(
+      "%d %d %d %d %s fillbox\n",
+      $x, $y, $x + $self->width, $y - $self->height,
+      PostScript::File::str($background)
+    ));
+  }
+}; # end before draw
+
+
 sub draw_standard_border
 {
   my ($self, $x, $y, $rpt) = @_;
@@ -172,9 +193,9 @@ PostScript::Report::Role::Component - Something that can be drawn
 
 =head1 VERSION
 
-This document describes version 0.01 of
-PostScript::Report::Role::Component, released October 22, 2009
-as part of PostScript-Report version 0.02.
+This document describes version 0.03 of
+PostScript::Report::Role::Component, released October 28, 2009
+as part of PostScript-Report version 0.03.
 
 =head1 DESCRIPTION
 
@@ -203,6 +224,21 @@ This controls text alignment.  It may be C<left>, C<center>, or
 C<right>.
 
 
+=head3 background
+
+This is the background color for the Component.  The color is a number
+in the range 0 to 1 (where 0 is black and 1 is white) for a grey
+background, or an arrayref of three numbers C<[ Red, Green, Blue ]>
+where each number is in the range 0 to 1.
+
+In addition, you can specify an RGB color in the HTML hex triplet form
+prefixed by C<#> (like C<#FFFF00> or C<#FF0> for yellow).
+
+Unlike the other formatting attributes, its value is not actually
+inherited, but since a Container draws the background for all its
+Components, the effect is the same.
+
+
 =head3 border
 
 This is the border style.  It may be 1 for a solid border or 0 for no
@@ -247,7 +283,10 @@ whose value can be inherited from the parent are marked (Inherited).
 =head3 padding_bottom
 
 (Inherited) This is the amount of space between the bottom of the
-component and the baseline of the text inside it.
+component and the baseline of the text inside it.  If this is too
+small, then the descenders (on letters like "p" and "y") will be cut
+off.  (The exact minimum necessary depends on the selected font and
+size.)
 
 
 =head3 padding_side
@@ -282,6 +321,8 @@ will probably never deal with it directly.
 
 This method draws the component on the current page of the report at
 position C<$x>, C<$y>.  This method must be provided by the component.
+The Component role provides a C<before draw> modifier to draw the
+component's background.
 
 
 =head2 draw_standard_border
@@ -333,6 +374,44 @@ additional initialization, such as calculating C<height> or C<width>.
 Also, the component should add its standard procedures to
 C<< $report->ps_functions >>.
 
+=head1 SEE ALSO
+
+The following components are available by default:
+
+=over
+
+=item L<Checkbox|PostScript::Report::Checkbox>
+
+This displays a box, which contains a checkmark if the associated
+value is true.
+
+=item L<Field|PostScript::Report::Field>
+
+This is a standard text field.
+
+=item L<FieldTL|PostScript::Report::FieldTL>
+
+This is a text field with a label in the corner.  It also (optionally)
+supports multiple lines with word wrap.
+
+=item L<HBox|PostScript::Report::HBox>
+
+This Container draws its children in a horizontal row.
+
+=item L<Image|PostScript::Report::Image>
+
+This allows you to include an EPS file.
+
+=item L<Spacer|PostScript::Report::Spacer>
+
+This is just an empty box for padding.
+
+=item L<VBox|PostScript::Report::VBox>
+
+This Container draws its children in a vertical column.
+
+=back
+
 =head1 INCOMPATIBILITIES
 
 None reported.
